difflicious.circe.JsonDiffer
See theJsonDiffer companion object
final class JsonDiffer extends Differ[Json]
Attributes
- Companion
- object
- Graph
-
- Supertypes
-
trait Differ[Json]trait ConfigureMethods[Json]class Objecttrait Matchableclass Any
Members list
Type members
Types
Value members
Concrete methods
Attributes
- Definition Classes
-
Differ
Inherited methods
Attributes
- Inherited from:
- ConfigureMethods
final def configureRaw(path: ConfigurePath, operation: ConfigureOp): Either[ConfigureError, Differ[Json]]
Attempt to change the configuration of this Differ. If successful, a new differ with the updated configuration will be returned.
Attempt to change the configuration of this Differ. If successful, a new differ with the updated configuration will be returned.
The configuration change can fail due to
- bad "path" that does not match the internal structure of the Differ
- The path resolved correctly, but the configuration update operation cannot be applied for that part of the Differ (e.g. wrong type or wrong operation)
Value parameters
- operation
-
The configuration change operation you want to perform on the target sub-Differ
- path
-
The path to traverse to the sub-Differ
Attributes
- Inherited from:
- Differ
Attributes
- Inherited from:
- Differ
Attributes
- Inherited from:
- Differ
Attributes
- Inherited from:
- ConfigureMethods
Attributes
- Inherited from:
- ConfigureMethods
Attributes
- Inherited from:
- Differ
Inherited fields
Attributes
- Inherited from:
- ConfigureMethods
In this article